@@ -15,8 +15,9 @@
 # limitations under the License.
 #
 
-
 from .services.connection_service import ConnectionServiceClient
+from .types.connection import AwsCrossAccountRole
+from .types.connection import AwsProperties
 from .types.connection import CloudSqlCredential
 from .types.connection import CloudSqlProperties
 from .types.connection import Connection
@@ -29,6 +30,8 @@ from .types.connection import UpdateConnectionRequest
 
 
 __all__ = (
+    "AwsCrossAccountRole",
+    "AwsProperties",
     "CloudSqlCredential",
     "CloudSqlProperties",
     "Connection",
