@@ -15,13 +15,15 @@
 # limitations under the License.
 #
 
-from typing import Callable, Dict, Tuple
+import warnings
+from typing import Callable, Dict, Optional, Sequence, Tuple
 
 from google.api_core import grpc_helpers  # type: ignore
+from google.api_core import gapic_v1  # type: ignore
+from google import auth  # type: ignore
 from google.auth import credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 
-
 import grpc  # type: ignore
 
 from google.cloud.bigquery.connection_v1.types import connection
@@ -30,7 +32,7 @@ from google.iam.v1 import iam_policy_pb2 as iam_policy  # type: ignore
 from google.iam.v1 import policy_pb2 as policy  # type: ignore
 from google.protobuf import empty_pb2 as empty  # type: ignore
 
-from .base import ConnectionServiceTransport
+from .base import ConnectionServiceTransport, DEFAULT_CLIENT_INFO
 
 
 class ConnectionServiceGrpcTransport(ConnectionServiceTransport):
@@ -46,14 +48,21 @@ class ConnectionServiceGrpcTransport(ConnectionServiceTransport):
     top of HTTP/2); the ``grpcio`` package must be installed.
     """
 
+    _stubs: Dict[str, Callable]
+
     def __init__(
         self,
         *,
         host: str = "bigqueryconnection.googleapis.com",
         credentials: credentials.Credentials = None,
+        credentials_file: str = None,
+        scopes: Sequence[str] = None,
         channel: grpc.Channel = None,
         api_mtls_endpoint: str = None,
-        client_cert_source: Callable[[], Tuple[bytes, bytes]] = None
+        client_cert_source: Callable[[], Tuple[bytes, bytes]] = None,
+        ssl_channel_credentials: grpc.ChannelCredentials = None,
+        quota_project_id: Optional[str] = None,
+        client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiate the transport.
 
@@ -65,21 +74,39 @@ class ConnectionServiceGrpcTransport(ConnectionServiceTransport):
                 are specified, the client will attempt to ascertain the
                 credentials from the environment.
                 This argument is ignored if ``channel`` is provided.
+            credentials_file (Optional[str]): A file with credentials that can
+                be loaded with :func:`google.auth.load_credentials_from_file`.
+                This argument is ignored if ``channel`` is provided.
+            scopes (Optional(Sequence[str])): A list of scopes. This argument is
+                ignored if ``channel`` is provided.
             channel (Optional[grpc.Channel]): A ``Channel`` instance through
                 which to make calls.
-            api_mtls_endpoint (Optional[str]): The mutual TLS endpoint. If
-                provided, it overrides the ``host`` argument and tries to create
+            api_mtls_endpoint (Optional[str]): Deprecated. The mutual TLS endpoint.
+                If provided, it overrides the ``host`` argument and tries to create
                 a mutual TLS channel with client SSL credentials from
                 ``client_cert_source`` or applicatin default SSL credentials.
-            client_cert_source (Optional[Callable[[], Tuple[bytes, bytes]]]): A
-                callback to provide client SSL certificate bytes and private key
-                bytes, both in PEM format. It is ignored if ``api_mtls_endpoint``
-                is None.
+            client_cert_source (Optional[Callable[[], Tuple[bytes, bytes]]]):
+                Deprecated. A callback to provide client SSL certificate bytes and
+                private key bytes, both in PEM format. It is ignored if
+                ``api_mtls_endpoint`` is None.
+            ssl_channel_credentials (grpc.ChannelCredentials): SSL credentials
+                for grpc channel. It is ignored if ``channel`` is provided.
+            quota_project_id (Optional[str]): An optional project to use for billing
+                and quota.
+            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
+                The client info used to send a user-agent string along with
+                API requests. If ``None``, then default info will be used.
+                Generally, you only need to set this if you're developing
+                your own client library.
 
         Raises:
-          google.auth.exceptions.MutualTlsChannelError: If mutual TLS transport
+          google.auth.exceptions.MutualTLSChannelError: If mutual TLS transport
               creation failed for any reason.
+          google.api_core.exceptions.DuplicateCredentialArgs: If both ``credentials``
+              and ``credentials_file`` are passed.
         """
+        self._ssl_channel_credentials = ssl_channel_credentials
+
         if channel:
             # Sanity check: Ensure that channel and credentials are not both
             # provided.
@@ -87,13 +114,24 @@ class ConnectionServiceGrpcTransport(ConnectionServiceTransport):
 
             # If a channel was explicitly provided, set it.
             self._grpc_channel = channel
+            self._ssl_channel_credentials = None
         elif api_mtls_endpoint:
+            warnings.warn(
+                "api_mtls_endpoint and client_cert_source are deprecated",
+                DeprecationWarning,
+            )
+
             host = (
                 api_mtls_endpoint
                 if ":" in api_mtls_endpoint
                 else api_mtls_endpoint + ":443"
             )
 
+            if credentials is None:
+                credentials, _ = auth.default(
+                    scopes=self.AUTH_SCOPES, quota_project_id=quota_project_id
+                )
+
             # Create SSL credentials with client_cert_source or application
             # default SSL credentials.
             if client_cert_source:
@@ -105,23 +143,54 @@ class ConnectionServiceGrpcTransport(ConnectionServiceTransport):
                 ssl_credentials = SslCredentials().ssl_credentials
 
             # create a new channel. The provided one is ignored.
-            self._grpc_channel = grpc_helpers.create_channel(
+            self._grpc_channel = type(self).create_channel(
                 host,
                 credentials=credentials,
+                credentials_file=credentials_file,
                 ssl_credentials=ssl_credentials,
-                scopes=self.AUTH_SCOPES,
+                scopes=scopes or self.AUTH_SCOPES,
+                quota_project_id=quota_project_id,
+            )
+            self._ssl_channel_credentials = ssl_credentials
+        else:
+            host = host if ":" in host else host + ":443"
+
+            if credentials is None:
+                credentials, _ = auth.default(
+                    scopes=self.AUTH_SCOPES, quota_project_id=quota_project_id
+                )
+
+            # create a new channel. The provided one is ignored.
+            self._grpc_channel = type(self).create_channel(
+                host,
+                credentials=credentials,
+                credentials_file=credentials_file,
+                ssl_credentials=ssl_channel_credentials,
+                scopes=scopes or self.AUTH_SCOPES,
+                quota_project_id=quota_project_id,
             )
 
-        # Run the base constructor.
-        super().__init__(host=host, credentials=credentials)
         self._stubs = {}  # type: Dict[str, Callable]
 
+        # Run the base constructor.
+        super().__init__(
+            host=host,
+            credentials=credentials,
+            credentials_file=credentials_file,
+            scopes=scopes or self.AUTH_SCOPES,
+            quota_project_id=quota_project_id,
+            client_info=client_info,
+        )
+
     @classmethod
     def create_channel(
         cls,
         host: str = "bigqueryconnection.googleapis.com",
         credentials: credentials.Credentials = None,
-        **kwargs
+        credentials_file: str = None,
+        scopes: Optional[Sequence[str]] = None,
+        quota_project_id: Optional[str] = None,
+        **kwargs,
     ) -> grpc.Channel:
         """Create and return a gRPC channel object.
         Args:
@@ -131,35 +200,42 @@ class ConnectionServiceGrpcTransport(ConnectionServiceTransport):
                 credentials identify this application to the service. If
                 none are specified, the client will attempt to ascertain
                 the credentials from the environment.
+            credentials_file (Optional[str]): A file with credentials that can
+                be loaded with :func:`google.auth.load_credentials_from_file`.
+                This argument is mutually exclusive with credentials.
+            scopes (Optional[Sequence[str]]): A optional list of scopes needed for this
+                service. These are only used when credentials are not specified and
+                are passed to :func:`google.auth.default`.
+            quota_project_id (Optional[str]): An optional project to use for billing
+                and quota.
             kwargs (Optional[dict]): Keyword arguments, which are passed to the
                 channel creation.
         Returns:
             grpc.Channel: A gRPC channel object.
+
+        Raises:
+            google.api_core.exceptions.DuplicateCredentialArgs: If both ``credentials``
+              and ``credentials_file`` are passed.
         """
+        scopes = scopes or cls.AUTH_SCOPES
         return grpc_helpers.create_channel(
-            host, credentials=credentials, scopes=cls.AUTH_SCOPES, **kwargs
+            host,
+            credentials=credentials,
+            credentials_file=credentials_file,
+            scopes=scopes,
+            quota_project_id=quota_project_id,
+            **kwargs,
         )
 
     @property
     def grpc_channel(self) -> grpc.Channel:
-        """Create the channel designed to connect to this service.
-
-        This property caches on the instance; repeated calls return
-        the same channel.
+        """Return the channel designed to connect to this service.
         """
-        # Sanity check: Only create a new channel if we do not already
-        # have one.
-        if not hasattr(self, "_grpc_channel"):
-            self._grpc_channel = self.create_channel(
-                self._host, credentials=self._credentials
-            )
-
-        # Return the channel from cache.
         return self._grpc_channel
 
     @property
     def create_connection(
-        self
+        self,
     ) -> Callable[
         [gcbc_connection.CreateConnectionRequest], gcbc_connection.Connection
     ]:
@@ -187,7 +263,7 @@ class ConnectionServiceGrpcTransport(ConnectionServiceTransport):
 
     @property
     def get_connection(
-        self
+        self,
     ) -> Callable[[connection.GetConnectionRequest], connection.Connection]:
         r"""Return a callable for the get connection method over gRPC.
 
@@ -213,7 +289,7 @@ class ConnectionServiceGrpcTransport(ConnectionServiceTransport):
 
     @property
     def list_connections(
-        self
+        self,
     ) -> Callable[
         [connection.ListConnectionsRequest], connection.ListConnectionsResponse
     ]:
@@ -241,7 +317,7 @@ class ConnectionServiceGrpcTransport(ConnectionServiceTransport):
 
     @property
     def update_connection(
-        self
+        self,
     ) -> Callable[
         [gcbc_connection.UpdateConnectionRequest], gcbc_connection.Connection
     ]:
@@ -271,7 +347,7 @@ class ConnectionServiceGrpcTransport(ConnectionServiceTransport):
 
     @property
     def delete_connection(
-        self
+        self,
     ) -> Callable[[connection.DeleteConnectionRequest], empty.Empty]:
         r"""Return a callable for the delete connection method over gRPC.
 
@@ -297,7 +373,7 @@ class ConnectionServiceGrpcTransport(ConnectionServiceTransport):
 
     @property
     def get_iam_policy(
-        self
+        self,
     ) -> Callable[[iam_policy.GetIamPolicyRequest], policy.Policy]:
         r"""Return a callable for the get iam policy method over gRPC.
 
@@ -325,15 +401,15 @@ class ConnectionServiceGrpcTransport(ConnectionServiceTransport):
 
     @property
     def set_iam_policy(
-        self
+        self,
     ) -> Callable[[iam_policy.SetIamPolicyRequest], policy.Policy]:
         r"""Return a callable for the set iam policy method over gRPC.
 
         Sets the access control policy on the specified resource.
         Replaces any existing policy.
 
-        Can return Public Errors: NOT_FOUND, INVALID_ARGUMENT and
-        PERMISSION_DENIED
+        Can return ``NOT_FOUND``, ``INVALID_ARGUMENT``, and
+        ``PERMISSION_DENIED`` errors.
 
         Returns:
             Callable[[~.SetIamPolicyRequest],
@@ -355,7 +431,7 @@ class ConnectionServiceGrpcTransport(ConnectionServiceTransport):
 
     @property
     def test_iam_permissions(
-        self
+        self,
     ) -> Callable[
         [iam_policy.TestIamPermissionsRequest], iam_policy.TestIamPermissionsResponse
     ]:
@@ -363,7 +439,7 @@ class ConnectionServiceGrpcTransport(ConnectionServiceTransport):
 
         Returns permissions that a caller has on the specified resource.
         If the resource does not exist, this will return an empty set of
-        permissions, not a NOT_FOUND error.
+        permissions, not a ``NOT_FOUND`` error.
 
         Note: This operation is designed to be used for building
         permission-aware UIs and command-line tools, not for
